Module raphtory::algorithms::algorithm_result
source · Structs
- A generic
AlgorithmResultstruct that represents the result of an algorithm computation.
AlgorithmResult struct that represents the result of an algorithm computation.