Module components

Module components 

Traits

LargestConnectedComponent
Gives the large connected component of a graph. The large connected component is the largest (i.e., with the highest number of nodes) connected sub-graph of the network.

Functions

in_component
Computes the in-component of a given node in the graph
in_component_filtered
Computes the in-component of a given node in the filtered graph
in_components
Computes the in components of each node in the graph
in_components_filtered
Computes the in components of each node in the filtered graph
out_component
Computes the out-component of a given node in the graph
out_component_filtered
Computes the out-component of a given node in the filtered graph
out_components
Computes the out components of each node in the graph
out_components_filtered
Computes the out components of each node in the filtered graph
strongly_connected_components
Computes the strongly connected components of a graph using Tarjan’s Strongly Connected Components algorithm
weakly_connected_components
Computes the connected community_detection of a graph using the Simple Connected Components algorithm