Function weakly_connected_components

pub fn weakly_connected_components<G>(
    graph: &G,
    iter_count: usize,
    threads: Option<usize>,
) -> AlgorithmResult<G, GID, GID>
Computes the connected community_detection of a graph using the Simple Connected Components algorithm

Arguments

  • g - A reference to the graph
  • iter_count - The number of iterations to run
  • threads - Number of threads to use

Returns:

An AlgorithmResult containing the mapping from the node to its component ID