Module raphtory::core

source ·
raphtory

raphtory is the core module for the raphtory library.

The raphtory library is a temporal graph analytics tool, which allows users to create and analyze graph data with time.

This crate provides the core data structures and functions for working with temporal graphs, as well as building and evaluating algorithms.

Note this module is not meant to be used as a standalone crate, but in conjunction with the raphtory_db crate.

For example code, please see the raphtory_db crate.

Supported Platforms

raphtory supports support for the following platforms:

Note they must have Rust 1.53 or later.

  • Linux
  • Windows
  • macOS

Modules

Enums

  • Denotes the direction of an edge. Can be incoming, outgoing or both.
  • Denotes the types of properties allowed to be stored in the graph.

Traits