pub struct History<'a, T>(pub T, _);Tuple Fields
0: TImplementations
Sourceimpl<'a, T: InternalHistoryOps + 'a> History<'a, T>
impl<'a, T: InternalHistoryOps + 'a> History<'a, T>
Sourcepub fn new(item: T) -> Self
pub fn new(item: T) -> Self
Create a new History wrapper around an object implementing InternalHistoryOps.
Sourcepub fn reverse(self) -> History<'a, ReversedHistoryOps<T>>
pub fn reverse(self) -> History<'a, ReversedHistoryOps<T>>
Reverse the iteration order of history items returned by iter and iter_rev.
Sourcepub fn t(self) -> HistoryTimestamp<T>
pub fn t(self) -> HistoryTimestamp<T>
Convert this History object to return timestamps (milliseconds since the Unix epoch) instead of EventTime.
Sourcepub fn dt(self) -> HistoryDateTime<T>
pub fn dt(self) -> HistoryDateTime<T>
Convert this History object to return datetimes instead of EventTime.
Sourcepub fn event_id(self) -> HistoryEventId<T>
pub fn event_id(self) -> HistoryEventId<T>
Convert this History object to return the event ids from EventTime entries.
Sourcepub fn intervals(self) -> Intervals<T>
pub fn intervals(self) -> Intervals<T>
Access the intervals (differences in milliseconds) between consecutive timestamps in this History object.
Sourcepub fn merge<R: InternalHistoryOps>(
self,
right: History<'_, R>,
) -> History<'_, MergedHistory<T, R>>
pub fn merge<R: InternalHistoryOps>( self, right: History<'_, R>, ) -> History<'_, MergedHistory<T, R>>
Merge this History with another History.
Sourcepub fn iter(&self) -> BoxedLIter<'_, EventTime>
pub fn iter(&self) -> BoxedLIter<'_, EventTime>
Iterate over EventTime entries in chronological order.
Sourcepub fn iter_rev(&self) -> BoxedLIter<'_, EventTime>
pub fn iter_rev(&self) -> BoxedLIter<'_, EventTime>
Iterate over EventTime entries in reverse chronological order.
Sourcepub fn collect_rev(&self) -> Vec<EventTime>
pub fn collect_rev(&self) -> Vec<EventTime>
Collect all EventTime entries in reverse chronological order.
Sourcepub fn earliest_time(&self) -> Option<EventTime>
pub fn earliest_time(&self) -> Option<EventTime>
Get the earliest EventTime entry in this History.
Sourcepub fn latest_time(&self) -> Option<EventTime>
pub fn latest_time(&self) -> Option<EventTime>
Get the latest EventTime entry in this History.
Sourcepub fn first(&self) -> Option<EventTime>
pub fn first(&self) -> Option<EventTime>
Get the first item produced by forward iteration in this History.
Sourcepub fn last(&self) -> Option<EventTime>
pub fn last(&self) -> Option<EventTime>
Get the first item produced by reverse iteration in this History.
Sourceimpl History<'_, EmptyHistory>
impl History<'_, EmptyHistory>
Sourcepub fn create_empty() -> Self
pub fn create_empty() -> Self
Create an empty history.
Sourceimpl<T: IntoArcDynHistoryOps> History<'_, T>
impl<T: IntoArcDynHistoryOps> History<'_, T>
Sourcepub fn into_arc_dyn(self) -> History<'static, Arc<dyn InternalHistoryOps>>
pub fn into_arc_dyn(self) -> History<'static, Arc<dyn InternalHistoryOps>>
Convert this history into an ArcSend + Sync). Particularly useful for Python.