Re-exports
pub use core_ops::*;
Modules
Structs
Enums
Traits
- Get a base for inheriting methods
- Marker trait to indicate that an object is a valid graph view
- Trait for marking a graph view as immutable to avoid conflicts when implementing conversions for mutable and immutable views
- Trait for marking a struct as not dynamically dispatched. Used to avoid conflicts when implementing
Fromfor dynamic wrappers. - Methods for defining time windowing semantics for a graph