EdgeView

Struct EdgeView 

pub struct EdgeView<G> {
    pub graph: G,
    pub edge: EdgeRef,
}
A view of an edge in the graph.

Fields

graph: G

A view of an edge in the graph.

edge: EdgeRef

A reference to the edge.

Implementations

Source

impl<'graph, G: GraphViewOps<'graph>> EdgeView<G>

pub fn new(graph: G, edge: EdgeRef) -> Self

Source

impl<G: Clone> EdgeView<&G>

pub fn cloned(&self) -> EdgeView<G>

Source

impl<G> EdgeView<G>

pub fn as_ref(&self) -> EdgeView<&G>

Source

impl<G: IntoDynamic> EdgeView<G>

Source

impl<G: GraphView> EdgeView<G>

Source

impl<G: StaticGraphViewOps + InternalAdditionOps<Error = GraphError> + InternalPropertyAdditionOps<Error = GraphError> + InternalDeletionOps<Error = GraphError>> EdgeView<G>

pub fn delete<T: TryIntoInputTime>( &self, t: T, layer: Option<&str>, ) -> Result<(), GraphError>

Source

impl<G: StaticGraphViewOps + PropertyAdditionOps + AdditionOps> EdgeView<G>

pub fn add_metadata<C: CollectProperties>( &self, properties: C, layer: Option<&str>, ) -> Result<(), GraphError>

Add metadata for the edge

Arguments
  • properties - Property key-value pairs to add
  • layer - The layer to which properties should be added. If the edge view is restricted to a single layer, ‘None’ will add the properties to that layer and ‘Some(“name”)’ fails unless the layer matches the edge view. If the edge view is not restricted to a single layer, ‘None’ sets the properties on the default layer and ‘Some(“name”)’ sets the properties on layer ‘“name”’ and fails if that layer doesn’t exist.

Returns: Ok(()) if metadata added successfully. Err(GraphError) if the operation fails.

pub fn update_metadata<C: CollectProperties>( &self, props: C, layer: Option<&str>, ) -> Result<(), GraphError>

pub fn add_updates<C: CollectProperties, T: TryIntoInputTime>( &self, time: T, props: C, layer: Option<&str>, ) -> Result<(), GraphError>