Struct raphtory::db::graph::views::deletion_graph::PersistentGraph

source ·
pub struct PersistentGraph(/* private fields */);
A graph view where an edge remains active from the time it is added until it is explicitly marked as deleted.

Note that the graph will give you access to all edges that were added at any point in time, even those that are marked as deleted. The deletion only has an effect on the exploded edge view that are returned. An edge is included in a windowed view of the graph if it is considered active at any point in the window.

Implementations

source

impl PersistentGraph

source

pub fn new() -> Self

source

pub fn from_storage(storage: Arc<Storage>) -> Self

source

pub fn from_internal_graph(internal_graph: GraphStorage) -> Self

source

pub fn event_graph(&self) -> Graph

Get event graph