WindowedGraph

Struct WindowedGraph 

pub struct WindowedGraph<G> {
    pub graph: G,
    pub start: Option<EventTime>,
    pub end: Option<EventTime>,
}
A struct that represents a windowed view of a Graph.

Fields

graph: G

The underlying Graph object.

start: Option<EventTime>

The inclusive start time of the window.

end: Option<EventTime>

The exclusive end time of the window.

Implementations

Source

impl<'graph, G: GraphViewOps<'graph>> WindowedGraph<G>

A windowed graph is a graph that only allows access to nodes and edges within a time window.

This struct is used to represent a graph with a time window. It is constructed by providing a Graph object and a time range that defines the window.

Examples

use raphtory::db::api::view::*;
use raphtory::prelude::*;

let graph = Graph::new();
graph.add_edge(0, 1, 2, NO_PROPS, None).unwrap();
graph.add_edge(1, 2, 3, NO_PROPS, None).unwrap();
let windowed_graph = graph.window(0, 1);
pub fn new(graph: G, start: Option<EventTime>, end: Option<EventTime>) -> Self

Create a new windowed graph

Arguments
  • graph - The graph to create the windowed graph from
  • start - The inclusive start time of the window.
  • end - The exclusive end time of the window.

Returns:

A new windowed graph