Traits
- Largest
Connected Component - Gives the large connected component of a graph. The large connected component is the largest (i.e., with the highest number of nodes) connected sub-graph of the network.
Functions
- in_
component - Computes the in-component of a given node in the graph
- in_
component_ filtered - Computes the in-component of a given node in the filtered graph
- in_
components - Computes the in components of each node in the graph
- in_
components_ filtered - Computes the in components of each node in the filtered graph
- out_
component - Computes the out-component of a given node in the graph
- out_
component_ filtered - Computes the out-component of a given node in the filtered graph
- out_
components - Computes the out components of each node in the graph
- out_
components_ filtered - Computes the out components of each node in the filtered graph
- strongly_
connected_ components - Computes the strongly connected components of a graph using Tarjan’s Strongly Connected Components algorithm
- weakly_
connected_ components - Computes the connected community_detection of a graph using the Simple Connected Components algorithm