pub fn weakly_connected_components<G>(
graph: &G,
iter_count: usize,
threads: Option<usize>,
) -> AlgorithmResult<G, GID, GID>where
G: StaticGraphViewOps,Expand description
Computes the connected community_detection of a graph using the Simple Connected Components algorithm
Arguments
g- A reference to the graphiter_count- The number of iterations to runthreads- Number of threads to use
Returns:
An AlgorithmResult containing the mapping from the node to its component ID