pub struct EdgeView<G> {
pub graph: G,
pub edge: EdgeRef,
}Expand description
A view of an edge in the graph.
Fields
graph: GA view of an edge in the graph.
edge: EdgeRefA reference to the edge.
Implementations
Sourceimpl<'graph, G: GraphViewOps<'graph>> EdgeView<G>
impl<'graph, G: GraphViewOps<'graph>> EdgeView<G>
Sourceimpl<G: IntoDynamic> EdgeView<G>
impl<G: IntoDynamic> EdgeView<G>
pub fn into_dynamic(self) -> EdgeView<DynamicGraph>
Sourceimpl<G: GraphView> EdgeView<G>
impl<G: GraphView> EdgeView<G>
pub fn deletions_hist(&self) -> BoxedLIter<'_, (EventTime, usize)>
Sourceimpl<G: StaticGraphViewOps + InternalAdditionOps<Error = GraphError> + InternalPropertyAdditionOps<Error = GraphError> + InternalDeletionOps<Error = GraphError>> EdgeView<G>
impl<G: StaticGraphViewOps + InternalAdditionOps<Error = GraphError> + InternalPropertyAdditionOps<Error = GraphError> + InternalDeletionOps<Error = GraphError>> EdgeView<G>
pub fn delete<T: TryIntoInputTime>( &self, t: T, layer: Option<&str>, ) -> Result<(), GraphError>
Sourceimpl<G: StaticGraphViewOps + PropertyAdditionOps + AdditionOps> EdgeView<G>
impl<G: StaticGraphViewOps + PropertyAdditionOps + AdditionOps> EdgeView<G>
Sourcepub fn add_metadata<C: CollectProperties>(
&self,
properties: C,
layer: Option<&str>,
) -> Result<(), GraphError>
pub fn add_metadata<C: CollectProperties>( &self, properties: C, layer: Option<&str>, ) -> Result<(), GraphError>
Add metadata for the edge
Arguments
properties- Property key-value pairs to addlayer- The layer to which properties should be added. If the edge view is restricted to a single layer, ‘None’ will add the properties to that layer and ‘Some(“name”)’ fails unless the layer matches the edge view. If the edge view is not restricted to a single layer, ‘None’ sets the properties on the default layer and ‘Some(“name”)’ sets the properties on layer ‘“name”’ and fails if that layer doesn’t exist.
Returns: Ok(()) if metadata added successfully. Err(GraphError) if the operation fails.
pub fn update_metadata<C: CollectProperties>( &self, props: C, layer: Option<&str>, ) -> Result<(), GraphError>
pub fn add_updates<C: CollectProperties, T: TryIntoInputTime>( &self, time: T, props: C, layer: Option<&str>, ) -> Result<(), GraphError>