Struct raphtory::db::graph::views::deletion_graph::PersistentGraph
source · pub struct PersistentGraph(/* private fields */);Expand description
A graph view where an edge remains active from the time it is added until it is explicitly marked as deleted.
Note that the graph will give you access to all edges that were added at any point in time, even those that are marked as deleted. The deletion only has an effect on the exploded edge view that are returned. An edge is included in a windowed view of the graph if it is considered active at any point in the window.
Implementations
sourceimpl PersistentGraph
impl PersistentGraph
pub fn new() -> Self
pub fn from_storage(storage: Arc<Storage>) -> Self
pub fn from_internal_graph(internal_graph: GraphStorage) -> Self
sourcepub fn event_graph(&self) -> Graph
pub fn event_graph(&self) -> Graph
Get event graph